import { ValidationError } from 'class-validator';
import { eRfidCertificateType } from '../../../../consts';
import { AllowPrimitives } from '../../../../types';
/**
* Rfid certificates data
*/
export interface iRRfidCertificate {
    /**
    * Certificate type
    * @type {eRfidCertificateType}
    */
    certificateType: eRfidCertificateType;
    /**
    * Public key algorithm
    * @type {string}
    */
    publicKeyAlgorithm: string;
    /**
    * Signature algorithm
    * @type {string}
    */
    signatureAlgorithm: string;
    /**
    * Issuer
    * @type {string}
    */
    issuer: string;
    /**
    * Subject
    * @type {string}
    */
    subject: string;
    /**
    * Valid from
    * @type {string}
    */
    validFrom: string;
    /**
    * Valid to
    * @type {string}
    */
    validTo: string;
}
/**
* Rfid certificates data
*/
export declare class RRfidCertificate implements iRRfidCertificate {
    /**
    * Certificate type
    * @type {eRfidCertificateType}
    */
    certificateType: eRfidCertificateType;
    /**
    * Public key algorithm
    * @type {string}
    */
    publicKeyAlgorithm: string;
    /**
    * Signature algorithm
    * @type {string}
    */
    signatureAlgorithm: string;
    /**
    * Issuer
    * @type {string}
    */
    issuer: string;
    /**
    * Subject
    * @type {string}
    */
    subject: string;
    /**
    * Valid from
    * @type {string}
    */
    validFrom: string;
    /**
    * Valid from
    * @type {string}
    */
    validTo: string;
    /**
    * Create instance of RRfidDataGroupStatus from plain object
    * @param {AllowPrimitives<iRRfidCertificate>} input - plain object
    * @returns {RRfidCertificate}
    */
    static fromPlain: (input: AllowPrimitives<iRRfidCertificate>) => RRfidCertificate;
    /**
    * Gets validation errors of RRfidDataGroupStatus
    * @param {RRfidCertificate} input - input data
    * @returns {ValidationError[]} - array of validation errors
    */
    static getValidationErrors: (input: RRfidCertificate) => ValidationError[];
}
